@@ -34,6 +34,8 @@
 #include <netdb.h>
 #include <string.h>
 #include <stdbool.h>
+#include <signal.h>
+#include <sys/stat.h>
 #include "capture.h"
 #ifdef USE_EEP
 #include "capture_eep.h"
@@ -44,15 +46,54 @@
 #ifdef WITH_OPENSSL
 #include "capture_openssl.h"
 #endif
+#ifdef WITH_ZLIB
+#include <zlib.h>
+#endif
 #include "sip.h"
 #include "rtp.h"
 #include "setting.h"
 #include "util.h"
 
+#if __STDC_VERSION__ >= 201112L && __STDC_NO_ATOMICS__ != 1
+// modern C with atomics
+#include <stdatomic.h>
+typedef atomic_int signal_flag_type;
+#else
+// no atomics available
+typedef volatile sig_atomic_t signal_flag_type;
+#endif
+
 // Capture information
 capture_config_t capture_cfg =
 { 0 };
 
+signal_flag_type sighup_received = 0;
+
+void sighup_handler(int signum)
+{
+    sighup_received = 1;
+}
+
+#if defined(WITH_ZLIB)
+static ssize_t
+gzip_cookie_write(void *cookie, const char *buf, size_t size)
+{
+    return gzwrite((gzFile)cookie, (voidpc)buf, size);
+}
+
+static ssize_t
+gzip_cookie_read(void *cookie, char *buf, size_t size)
+{
+    return gzread((gzFile)cookie, (voidp)buf, size);
+}
+
+static int
+gzip_cookie_close(void *cookie)
+{
+    return gzclose((gzFile)cookie);
+}
+#endif
+
 void
 capture_init(size_t limit, bool rtp_capture, bool rotate, size_t pcap_buffer_size)
 {
@@ -63,6 +104,13 @@ capture_init(size_t limit, bool rtp_capture, bool rotate, size_t pcap_buffer_siz
     capture_cfg.paused = 0;
     capture_cfg.sources = vector_create(1, 1);
 
+    // set up SIGHUP handler
+    // the handler will be served by any of the running threads
+    // so we just set a flag and check it in dump_packet
+    // so it is only acted upon before then next packed will be dumped
+    if (signal(SIGHUP, sighup_handler) == SIG_ERR)
+        exit(EXIT_FAILURE);
+
     // Fixme
     if (setting_has_value(SETTING_CAPTURE_STORAGE, "none")) {
         capture_cfg.storage = CAPTURE_STORAGE_NONE;
@@ -104,7 +152,7 @@ capture_deinit()
 }
 
 int
-capture_online(const char *dev, const char *outfile)
+capture_online(const char *dev)
 {
     capture_info_t *capinfo;
 
@@ -155,9 +203,12 @@ capture_online(const char *dev, const char *outfile)
         return 2;
     }
 
+    // Set capture thread function
+    capinfo->capture_fn = capture_thread;
 
     // Store capture device
     capinfo->device = dev;
+    capinfo->ispcap = true;
 
     // Get datalink to parse packets correctly
     capinfo->link = pcap_datalink(capinfo->handle);
@@ -175,20 +226,11 @@ capture_online(const char *dev, const char *outfile)
     // Add this capture information as packet source
     capture_add_source(capinfo);
 
-    // If requested store packets in a dump file
-    if (outfile && !capture_cfg.pd) {
-        if ((capture_cfg.pd = dump_open(outfile)) == NULL) {
-            fprintf(stderr, "Couldn't open output dump file %s: %s\n", outfile,
-                    pcap_geterr(capinfo->handle));
-            return 2;
-        }
-    }
-
     return 0;
 }
 
 int
-capture_offline(const char *infile, const char *outfile)
+capture_offline(const char *infile)
 {
     capture_info_t *capinfo;
     FILE *fstdin;
@@ -207,14 +249,45 @@ capture_offline(const char *infile, const char *outfile)
         infile = "/dev/stdin";
     }
 
+    // Set capture thread function
+    capinfo->capture_fn = capture_thread;
+
     // Set capture input file
     capinfo->infile = infile;
+    capinfo->ispcap = true;
 
     // Open PCAP file
     if ((capinfo->handle = pcap_open_offline(infile, errbuf)) == NULL) {
+#if defined(HAVE_FOPENCOOKIE) && defined(WITH_ZLIB)
+        // we can't directly parse the file as pcap - could it be gzip compressed?
+        gzFile zf = gzopen(infile, "rb");
+        if (!zf)
+            goto openerror;
+
+        static cookie_io_functions_t cookiefuncs = {
+            gzip_cookie_read, NULL, NULL, gzip_cookie_close
+        };
+
+        // reroute the file access functions
+        // use the gzip read+close functions when accessing the file
+        FILE *fp = fopencookie(zf, "r", cookiefuncs);
+        if (!fp)
+        {
+            gzclose(zf);
+            goto openerror;
+        }
+
+        if ((capinfo->handle = pcap_fopen_offline(fp, errbuf)) == NULL) {
+openerror:
+            fprintf(stderr, "Couldn't open pcap file %s: %s\n", infile, errbuf);
+            return 1;
+        }
+    }
+#else
         fprintf(stderr, "Couldn't open pcap file %s: %s\n", infile, errbuf);
         return 1;
     }
+#endif
 
     // Reopen tty for ncurses after pcap have used stdin
     if (!strncmp(infile, "/dev/stdin", 10)) {
@@ -240,15 +313,6 @@ capture_offline(const char *infile, const char *outfile)
     // Add this capture information as packet source
     capture_add_source(capinfo);
 
-    // If requested store packets in a dump file
-    if (outfile && !capture_cfg.pd) {
-        if ((capture_cfg.pd = dump_open(outfile)) == NULL) {
-            fprintf(stderr, "Couldn't open output dump file %s: %s\n", outfile,
-                    pcap_geterr(capinfo->handle));
-            return 2;
-        }
-    }
-
     return 0;
 }
 
@@ -394,7 +458,7 @@ parse_packet(u_char *info, const struct pcap_pkthdr *header, const u_char *packe
         capture_eep_send(pkt);
 #endif
         // Store this packets in output file
-        dump_packet(capture_cfg.pd, pkt);
+        capture_dump_packet(pkt);;
         // If storage is disabled, delete frames payload
         if (capture_cfg.storage == 0) {
             packet_free_frames(pkt);
@@ -744,6 +808,12 @@ capture_packet_reasm_tcp(capture_info_t *capinfo, packet_t *packet, struct tcphd
         sng_free(new_payload);
     }
 
+    // Check if packet is too large after assembly
+    if (pkt->payload_len > MAX_CAPTURE_LEN) {
+        vector_remove(capinfo->tcp_reasm, pkt);
+        return NULL;
+    }
+
     // Store full payload content
     memset(full_payload, 0, MAX_CAPTURE_LEN);
     memcpy(full_payload, pkt->payload, pkt->payload_len);
@@ -931,7 +1001,9 @@ capture_close()
                  * you can only break pcap_loop from within the same thread.
                  * @see: https://www.tcpdump.org/manpages/pcap_breakloop.3pcap.html
                  */
-                pcap_breakloop(capinfo->handle);
+                if (capinfo->ispcap) {
+                    pcap_breakloop(capinfo->handle);
+                }
                 pthread_cancel(capinfo->capture_t);
                 pthread_join(capinfo->capture_t, NULL);
             }
@@ -952,7 +1024,7 @@ capture_launch_thread(capture_info_t *capinfo)
     while ((capinfo = vector_iterator_next(&it))) {
         // Mark capture as running
         capinfo->running = true;
-        if (pthread_create(&capinfo->capture_t, &attr, (void *) capture_thread, capinfo)) {
+        if (pthread_create(&capinfo->capture_t, &attr, (void *) capinfo->capture_fn, capinfo)) {
             return 1;
         }
     }
@@ -961,7 +1033,7 @@ capture_launch_thread(capture_info_t *capinfo)
     return 0;
 }
 
-void
+void *
 capture_thread(void *info)
 {
     capture_info_t *capinfo = (capture_info_t *) info;
@@ -969,6 +1041,8 @@ capture_thread(void *info)
     // Parse available packets
     pcap_loop(capinfo->handle, -1, parse_packet, (u_char *) capinfo);
     capinfo->running = false;
+
+    return NULL;
 }
 
 int
@@ -1204,6 +1278,40 @@ capture_packet_time_sorter(vector_t *vector, void *item)
     vector_insert(vector, item, 0);
 }
 
+void
+capture_set_dumper(pcap_dumper_t *dumper, ino_t dump_inode)
+{
+    capture_cfg.pd = dumper;
+    capture_cfg.dump_inode = dump_inode;
+}
+
+void
+capture_dump_packet(packet_t *packet)
+{
+    if (sighup_received && capture_cfg.pd) {
+        // we got a SIGHUP: reopen the dump file because it could have been renamed
+        // we don't need to care about locking or other threads accessing in parallel
+        // because dump_open ensures count(capture_cfg.sources) == 1
+
+        // check if the file has actually changed
+        // only reopen if it has, otherwise we would overwrite the existing one
+        struct stat sb;
+        if (stat(capture_cfg.dumpfilename, &sb) == -1 ||
+            sb.st_ino != capture_cfg.dump_inode)
+        {
+            pcap_dump_close(capture_cfg.pd);
+            capture_cfg.pd = dump_open(capture_cfg.dumpfilename, &capture_cfg.dump_inode);
+        }
+
+        sighup_received = 0;
+
+        // error reopening capture file: we can't capture anymore
+        if (!capture_cfg.pd)
+            return;
+    }
+
+    dump_packet(capture_cfg.pd, packet);
+}
 
 int8_t
 datalink_size(int datalink)
@@ -1237,6 +1345,10 @@ datalink_size(int datalink)
         case DLT_LINUX_SLL:
             return 16;
 #endif
+#ifdef DLT_LINUX_SLL2
+        case DLT_LINUX_SLL2:
+            return 20;
+#endif
 #ifdef DLT_IPNET
         case DLT_IPNET:
             return 24;
@@ -1248,14 +1360,67 @@ datalink_size(int datalink)
 
 }
 
+bool
+is_gz_filename(const char *filename)
+{
+    // does the filename end on ".gz"?
+    char *dotpos = strrchr(filename, '.');
+    if (dotpos && (strcmp(dotpos, ".gz") == 0))
+        return true;
+    else
+        return false;
+}
+
 pcap_dumper_t *
-dump_open(const char *dumpfile)
+dump_open(const char *dumpfile, ino_t* dump_inode)
 {
     capture_info_t *capinfo;
 
     if (vector_count(capture_cfg.sources) == 1) {
+        capture_cfg.dumpfilename = dumpfile;
         capinfo = vector_first(capture_cfg.sources);
-        return pcap_dump_open(capinfo->handle, dumpfile);
+
+        FILE *fp = fopen(dumpfile,"wb+");
+        if (!fp)
+            return NULL;
+
+        struct stat sb;
+        if (fstat(fileno(fp), &sb) == -1)
+            return NULL;
+
+        if (dump_inode) {
+            // read out the files inode, allows to later check if it has changed
+            struct stat sb;
+            if (fstat(fileno(fp), &sb) == -1)
+                return NULL;
+            *dump_inode = sb.st_ino;
+        }
+
+        if (is_gz_filename(dumpfile))
+        {
+#if defined(HAVE_FOPENCOOKIE) && defined(WITH_ZLIB)
+            // create a gzip file stream out of the already opened file
+            gzFile zf = gzdopen(fileno(fp), "w");
+            if (!zf)
+                return NULL;
+
+            static cookie_io_functions_t cookiefuncs = {
+                NULL, gzip_cookie_write, NULL, gzip_cookie_close
+            };
+
+            // reroute the file access functions
+            // use the gzip write+close functions when accessing the file
+            fp = fopencookie(zf, "w", cookiefuncs);
+            if (!fp)
+                return NULL;
+#else
+            // no support for gzip compressed pcap files compiled in -> abort
+            fclose(fp);
+            return NULL;
+#endif
+        }
+
+        return pcap_dump_fopen(capinfo->handle, fp);
     }
     return NULL;
 }
