@@ -55,7 +55,7 @@ filter_create(ui_t *ui)
     const char *method, *payload;
 
     // Cerate a new indow for the panel and form
-    ui_panel_create(ui, 17, 50);
+    ui_panel_create(ui, 18, 50);
 
     // Initialize Filter panel specific data
     info = sng_malloc(sizeof(filter_info_t));
@@ -74,6 +74,7 @@ filter_create(ui_t *ui)
     info->fields[FLD_FILTER_SUBSCRIBE] = new_field(1, 1, 11, 15, 0, 0);
     info->fields[FLD_FILTER_NOTIFY] = new_field(1, 1, 12, 15, 0, 0);
     info->fields[FLD_FILTER_INFO] = new_field(1, 1, 13, 15, 0, 0);
+    info->fields[FLD_FILTER_KDMQ] = new_field(1, 1, 14, 15, 0, 0);
     info->fields[FLD_FILTER_OPTIONS] = new_field(1, 1, 9, 37, 0, 0);
     info->fields[FLD_FILTER_PUBLISH] = new_field(1, 1, 10, 37, 0, 0);
     info->fields[FLD_FILTER_MESSAGE] = new_field(1, 1, 11, 37, 0, 0);
@@ -94,6 +95,7 @@ filter_create(ui_t *ui)
     field_opts_off(info->fields[FLD_FILTER_SUBSCRIBE], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_NOTIFY], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_INFO], O_AUTOSKIP);
+    field_opts_off(info->fields[FLD_FILTER_KDMQ], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_OPTIONS], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_PUBLISH], O_AUTOSKIP);
     field_opts_off(info->fields[FLD_FILTER_MESSAGE], O_AUTOSKIP);
@@ -129,6 +131,7 @@ filter_create(ui_t *ui)
     mvwprintw(ui->win, 11, 3, "SUBSCRIBE  [ ]");
     mvwprintw(ui->win, 12, 3, "NOTIFY     [ ]");
     mvwprintw(ui->win, 13, 3, "INFO       [ ]");
+    mvwprintw(ui->win, 14, 3, "KDMQ       [ ]");
     mvwprintw(ui->win, 9, 25, "OPTIONS    [ ]");
     mvwprintw(ui->win, 10, 25, "PUBLISH    [ ]");
     mvwprintw(ui->win, 11, 25, "MESSAGE    [ ]");
@@ -159,6 +162,8 @@ filter_create(ui_t *ui)
                      strcasestr(method, sip_method_str(SIP_METHOD_NOTIFY)) ? "*" : "");
     set_field_buffer(info->fields[FLD_FILTER_INFO], 0,
                      strcasestr(method, sip_method_str(SIP_METHOD_INFO)) ? "*" : "");
+    set_field_buffer(info->fields[FLD_FILTER_KDMQ], 0,
+                     strcasestr(method, sip_method_str(SIP_METHOD_KDMQ)) ? "*" : "");
     set_field_buffer(info->fields[FLD_FILTER_OPTIONS], 0,
                      strcasestr(method, sip_method_str(SIP_METHOD_OPTIONS)) ? "*" : "");
     set_field_buffer(info->fields[FLD_FILTER_PUBLISH], 0,
@@ -274,6 +279,7 @@ filter_handle_key(ui_t *ui, int key)
                     case FLD_FILTER_SUBSCRIBE:
                     case FLD_FILTER_NOTIFY:
                     case FLD_FILTER_INFO:
+                    case FLD_FILTER_KDMQ:
                     case FLD_FILTER_OPTIONS:
                     case FLD_FILTER_PUBLISH:
                     case FLD_FILTER_MESSAGE:
@@ -378,6 +384,7 @@ filter_save_options(ui_t *ui)
             case FLD_FILTER_INFO:
             case FLD_FILTER_REFER:
             case FLD_FILTER_UPDATE:
+            case FLD_FILTER_KDMQ:
                 if (!strcmp(field_value, "*")) {
                     if (strlen(method_expr)) {
                         sprintf(method_expr + strlen(method_expr), ",%s", filter_field_method(field_id));
@@ -436,6 +443,9 @@ filter_field_method(int field_id)
         case FLD_FILTER_UPDATE:
             method = SIP_METHOD_UPDATE;
             break;
+        case FLD_FILTER_KDMQ:
+            method = SIP_METHOD_KDMQ;
+            break;
     }
 
     return sip_method_str(method);
