@@ -192,6 +192,9 @@ ui_wait_for_input()
     // While there are still panels
     while ((panel = panel_below(NULL))) {
 
+        if (was_sigterm_received())
+            return 0;
+
         // Get panel interface structure
         ui = ui_find_by_panel(panel);
 
@@ -445,12 +448,15 @@ draw_message_pos(WINDOW *win, sip_msg_t *msg, int starting)
             cur_line =payload + i + 1;
 
         // Move to the next line if line is filled or a we reach a line break
-        if (column > width || payload[i] == '\n') {
+        if (column > width - 1 || payload[i] == '\n') {
             line++;
             column = 0;
-            continue;
         }
 
+        // No need to print new line characters
+        if (payload[i] == '\n')
+            continue;
+
         // Put next character in position
         if (isascii(payload[i])) {
             mvwaddch(win, line, column++, payload[i]);
