@@ -61,7 +61,29 @@ filter_set(int type, const char *expr)
     // Set new expresion values
     filters[type].expr = (expr) ? strdup(expr) : NULL;
     filters[type].regex = regex;
+#elif defined(WITH_PCRE2)
+    pcre2_code *regex = NULL;
 
+    // If we have an expression, check if compiles before changing the filter
+    if (expr) {
+        int re_err = 0;
+        PCRE2_SIZE err_offset = 0;
+        uint32_t pcre_options = PCRE2_UNGREEDY | PCRE2_CASELESS;
+
+        // Check if we have a valid expression
+        if (!(regex = pcre2_compile((PCRE2_SPTR) expr, PCRE2_ZERO_TERMINATED, pcre_options, &re_err, &err_offset, NULL)))
+            return 1;
+    }
+
+    // Remove previous value
+    if (filters[type].expr) {
+        sng_free(filters[type].expr);
+        pcre2_code_free(filters[type].regex);
+    }
+
+    // Set new expresion values
+    filters[type].expr = (expr) ? strdup(expr) : NULL;
+    filters[type].regex = regex;
 #else
     regex_t regex;
     // If we have an expression, check if compiles before changing the filter
@@ -184,6 +206,11 @@ filter_check_expr(filter_t filter, const char *data)
 {
 #ifdef WITH_PCRE
         return pcre_exec(filter.regex, 0, data, strlen(data), 0, 0, 0, 0);
+#elif defined(WITH_PCRE2)
+    pcre2_match_data *match_data = pcre2_match_data_create_from_pattern(filter.regex, NULL);
+    int ret = pcre2_match(filter.regex, (PCRE2_SPTR) data, (PCRE2_SIZE) strlen(data), 0, 0, match_data, NULL);
+    pcre2_match_data_free(match_data);
+    return (ret == PCRE2_ERROR_NOMATCH) ? 1 : 0;
 #else
         // Call doesn't match this filter
         return regexec(&filter.regex, data, 0, NULL, 0);
