@@ -327,6 +327,8 @@ main(int argc, char* argv[])
         }
     }
 
+    setup_sigterm_handler();
+
 #if defined(WITH_GNUTLS) || defined(WITH_OPENSSL)
     // Set capture decrypt key file
     capture_set_keyfile(keyfile);
@@ -370,17 +372,24 @@ main(int argc, char* argv[])
     // If we have an input file, load it
     for (i = 0; i < vector_count(infiles); i++) {
         // Try to load file
-        if (capture_offline(vector_item(infiles, i), outfile) != 0)
+        if (capture_offline(vector_item(infiles, i)) != 0)
             return 1;
     }
 
     // If we have an input device, load it
     for (i = 0; i < vector_count(indevices); i++) {
         // Check if all capture data is valid
-        if (capture_online(vector_item(indevices, i), outfile) != 0)
+        if (capture_online(vector_item(indevices, i)) != 0)
             return 1;
     }
 
+    if (outfile)
+    {
+        ino_t dump_inode;
+        pcap_dumper_t *dumper = dump_open(outfile, &dump_inode);
+        capture_set_dumper(dumper, dump_inode);
+    }
+
     // Remove Input files vector
     vector_destroy(infiles);
 
@@ -436,13 +445,13 @@ main(int argc, char* argv[])
         ui_wait_for_input();
     } else {
         setbuf(stdout, NULL);
-        while(capture_is_running()) {
+        while(capture_is_running() && !was_sigterm_received()) {
             if (!quiet)
-                printf("\rDialog count: %d", sip_calls_count());
+                printf("\rDialog count: %d", sip_calls_count_unrotated());
             usleep(500 * 1000);
         }
         if (!quiet)
-            printf("\rDialog count: %d\n", sip_calls_count());
+            printf("\rDialog count: %d\n", sip_calls_count_unrotated());
     }
 
     // Capture deinit
